@@ -8,8 +8,11 @@ utils::globalVariables(
     "N",
     "NN",
     "n",
+    "samplenumb",
+    "correct",
     "TheMean",
     "TheSEM",
+    "TheSD",
     "CIMuliplier",
     "LowerBound",
     "UpperBound",
